@@ -1,9 +1,8 @@
-#  Licensed to the Apache Software Foundation (ASF) under one or more
-#  contributor license agreements.  See the NOTICE file distributed with
-#  this work for additional information regarding copyright ownership.
-#  The ASF licenses this file to You under the Apache License, Version 2.0
-#  (the "License"); you may not use this file except in compliance with
-#  the License.  You may obtain a copy of the License at
+#  Copyright 2017-2021 John Snow Labs
+#
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
 #
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
@@ -55,6 +54,7 @@ class ParamsGettersSetters(Params):
         paramName : str
             Name of the parameter
         """
+
         def r():
             try:
                 return self.getOrDefault(paramName)
@@ -71,6 +71,7 @@ class ParamsGettersSetters(Params):
         paramName : str
             Name of the parameter
         """
+
         def r(v):
             self.set(self.getParam(paramName), v)
             return self
@@ -389,3 +390,15 @@ class _LongformerLoader(ExtendedJavaWrapper):
         super(_LongformerLoader, self).__init__("com.johnsnowlabs.nlp.embeddings.LongformerEmbeddings.loadSavedModel",
                                                 path,
                                                 jspark)
+
+
+class _RoBertaSentenceLoader(ExtendedJavaWrapper):
+    def __init__(self, path, jspark):
+        super(_RoBertaSentenceLoader, self).__init__(
+            "com.johnsnowlabs.nlp.embeddings.RoBertaSentenceEmbeddings.loadSavedModel", path, jspark)
+
+
+class _XlmRoBertaSentenceLoader(ExtendedJavaWrapper):
+    def __init__(self, path, jspark):
+        super(_XlmRoBertaSentenceLoader, self).__init__(
+            "com.johnsnowlabs.nlp.embeddings.XlmRoBertaSentenceEmbeddings.loadSavedModel", path, jspark)
